"""
Put project's custom urls in this file
"""
from django.conf.urls import *


urlpatterns = patterns('',)
